==> ckan-2.2.1.tar.gz: ckan-2.2.1/ckan/public/base/i18n/el.js <==
{
  "": {
    "domain": "ckan",
    "lang": "el",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Παρουσιάστε ένα λάθος"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Είστε βέβαιοι ότι θέλετε να εκτελέσετε αυτή την ενέργεια;"
  ],
  "Cancel": [
    null,
    "Ακύρωση"
  ],
  "Confirm": [
    null,
    "Επιβεβαίωση"
  ],
  "Edit": [
    null,
    "Επεξεργασία"
  ],
  "Failed to load data API information": [
    null,
    "Αποτυχία φόρτωσης πληροφοριών από το API δεδομένων"
  ],
  "Follow": [
    null,
    "Ακολουθήστε"
  ],
  "Hide": [
    null,
    "Απόκρυψη"
  ],
  "Image": [
    null,
    "Εικόνα"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Δεδομένα εισόδου πολύ μικρά, πρέπει να είναι τουλάχιστον ένας χαρακτήρας"
  ],
  "Loading...": [
    null,
    "Φορτώνει...."
  ],
  "No matches found": [
    null,
    "Δεν βρέθηκε"
  ],
  "Please Confirm Action": [
    null,
    "Παρακαλώ Επιβεβαιώστε "
  ],
  "Remove": [
    null,
    "Αφαίρεση"
  ],
  "Resource uploaded": [
    null,
    "O πόρος μεταφορτώθηκε επιτυχώς"
  ],
  "Show more": [
    null,
    "Προβολή περισσοτέρων"
  ],
  "Start typing…": [
    null,
    "Ξεκινήστε να πληκτρολογείτε..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Υπάρχουν μη αποθηκευμένες αλλαγές στην φόρμα"
  ],
  "There is no API data to load for this resource": [
    null,
    "Δεν υπάρχουν δεδομένα από το API για αυτόν τον πόρο"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Αδυναμία επικύρωσης της μεταφόρτωσης"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Αδυναμία λήψης δεδομένων του αρχείου μεταφόρτωσης"
  ],
  "Unable to upload file": [
    null,
    "Αδυναμία μεταφόρτωσης του αρχείου"
  ],
  "Unfollow": [
    null,
    "Διακοπή ακολούθησης"
  ],
  "Upload": [
    null,
    "Ανεβάστε"
  ],
  "Upload a file": [
    null,
    "Φορτώστε ένα αρχείο"
  ],
  "show less": [
    null,
    "λιγότερα"
  ],
  "show more": [
    null,
    "περισσότερα"
  ]
}

==> ckan-2.2.3.tar.gz: ckan-2.2.3/ckan/public/base/i18n/el.js <==
{
  "": {
    "domain": "ckan",
    "lang": "el",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Παρουσιάστηκε σφάλμα"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Είστε βέβαιοι ότι θέλετε να εκτελέσετε αυτή την ενέργεια;"
  ],
  "Cancel": [
    null,
    "Ακύρωση"
  ],
  "Confirm": [
    null,
    "Επιβεβαίωση"
  ],
  "Edit": [
    null,
    "Επεξεργασία"
  ],
  "Failed to load data API information": [
    null,
    "Αποτυχία φόρτωσης πληροφοριών από το API δεδομένων"
  ],
  "Follow": [
    null,
    "Ακολουθήστε"
  ],
  "Hide": [
    null,
    "Απόκρυψη"
  ],
  "Image": [
    null,
    "Εικόνα"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Δεδομένα εισόδου πολύ μικρά, πρέπει να είναι τουλάχιστον ένας χαρακτήρας"
  ],
  "Link": [
    null,
    "Σύνδεσμος"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Δώστε σύνδεσμο σε ένα URL στο διαδίκτυο (μπορείτε επίσης να δώσετε έναν σύνδεσμο σε ένα API)"
  ],
  "Loading...": [
    null,
    "Φόρτωση..."
  ],
  "No matches found": [
    null,
    "Δεν βρέθηκαν αποτελέσματα"
  ],
  "Please Confirm Action": [
    null,
    "Παρακαλώ Επιβεβαιώστε"
  ],
  "Remove": [
    null,
    "Αφαίρεση"
  ],
  "Reorder resources": [
    null,
    "Επαναταξινόμηση πόρων"
  ],
  "Reset this": [
    null,
    "Επαναφορά"
  ],
  "Resource uploaded": [
    null,
    "O πόρος μεταφορτώθηκε επιτυχώς"
  ],
  "Save order": [
    null,
    "Αποθήκευση ταξινόμησης"
  ],
  "Saving...": [
    null,
    "Αποθήκευση..."
  ],
  "Show more": [
    null,
    "Προβολή περισσοτέρων"
  ],
  "Start typing…": [
    null,
    "Ξεκινήστε να πληκτρολογείτε..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Υπάρχουν μη αποθηκευμένες αλλαγές στην φόρμα"
  ],
  "There is no API data to load for this resource": [
    null,
    "Δεν υπάρχουν δεδομένα από το API για αυτόν τον πόρο"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Αδυναμία επικύρωσης της μεταφόρτωσης"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Αδυναμία λήψης δεδομένων του αρχείου μεταφόρτωσης"
  ],
  "Unable to upload file": [
    null,
    "Αδυναμία μεταφόρτωσης του αρχείου"
  ],
  "Unfollow": [
    null,
    "Διακοπή ακολούθησης"
  ],
  "Upload": [
    null,
    "Ανέβασμα Αρχείου"
  ],
  "Upload a file": [
    null,
    "Ανεβάστε ένα αρχείο"
  ],
  "Upload a file on your computer": [
    null,
    "Μεταφόρτωση αρχείου στον υπολογιστή σας"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Πραγματοποιείτε μεταφόρτωση αρχείου. Είστε σίγουροι ότι θέλετε να πλοηγηθείτε σε κάτι άλλο και να σταματήσετε αυτή τη μεταφόρτωση;"
  ],
  "show less": [
    null,
    "εμφάνιση λιγότερων"
  ],
  "show more": [
    null,
    "εμφάνιση περισσοτέρων"
  ]
}
